==> consumer-center-api-1.0.7-20170103.082456-2-sources.jar: cn/com/duiba/consumer/center/api/dto/SignLogDto.java <==
package cn.com.duiba.consumer.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by liuyao on 2016/12/21.
 * 签到日志表
 */
public class SignLogDto implements Serializable{

    public static final long serialVersionUID = 1053047858801268831L;
    public final static int STATUE_WITE = 0;
    public final static int STATUE_FAILD = 1;
    public final static int STATUE_SUCCESS = 2;

    private Long id;
    private Long logId;
    private String bizId;
    private Long consumerId;
    private Integer credits;
    private Integer signType;
    private Integer logStatue=0;
    private Date gmtCreate;
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getLogId() {
        return logId;
    }

    public void setLogId(Long logId) {
        this.logId = logId;
    }

    public String getBizId() {
        return bizId;
    }

    public void setBizId(String bizId) {
        this.bizId = bizId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Integer getCredits() {
        return credits;
    }

    public void setCredits(Integer credits) {
        this.credits = credits;
    }

    public Integer getSignType() {
        return signType;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }

    public Integer getLogStatue() {
        return logStatue;
    }

    public void setLogStatue(Integer logStatue) {
        this.logStatue = logStatue;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> consumer-center-api-1.2.0-20170309.065528-1-sources.jar: cn/com/duiba/consumer/center/api/dto/SignLogDto.java <==
package cn.com.duiba.consumer.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by liuyao on 2016/12/21.
 * 签到日志表
 */
public class SignLogDto implements Serializable{

    public static final long serialVersionUID = 1053047858801268831L;
    public static final  int STATUE_WITE = 0;
    public static final  int STATUE_FAILD = 1;
    public static final  int STATUE_SUCCESS = 2;

    private Long id;
    private Long logId;
    private String bizId;
    private Long consumerId;
    private Integer credits;
    private Integer signType;
    private Integer logStatue=0;
    private Date gmtCreate;
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getLogId() {
        return logId;
    }

    public void setLogId(Long logId) {
        this.logId = logId;
    }

    public String getBizId() {
        return bizId;
    }

    public void setBizId(String bizId) {
        this.bizId = bizId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Integer getCredits() {
        return credits;
    }

    public void setCredits(Integer credits) {
        this.credits = credits;
    }

    public Integer getSignType() {
        return signType;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }

    public Integer getLogStatue() {
        return logStatue;
    }

    public void setLogStatue(Integer logStatue) {
        this.logStatue = logStatue;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
